ProvisionManager class
Methods
-
connect(ScanResult scanResult, {BleConnectCallback? callback})
→ void
-
Initiates a connection to the specified Bluetooth device.
-
disconnect()
→ void
-
Disconnects from the currently connected device.
-
getSensorInstallInfo()
→ Stream<SensorInstallInfoEntity>
-
Retrieves the installation information for the sensor.
-
getSensorState()
→ Stream<SensorConfigStateEntity>
-
Retrieves the current state of the sensor.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
scanWiFiList(WiFiListCallback callback)
→ void
-
Initiates a scan for available Wi-Fi networks.
-
sendConfigure(String orgId, String certPem, String publicKey, String privateKey, String url, String? ssid, String password, {dynamic onWriteFailure(Exception)?})
→ Stream<SensorConfigStateEntity>
-
Sends configuration data for the sensor.
-
sendSensorConfigFinish(SensorConfigFinishCallback callback)
→ void
-
Sends a signal to indicate that the sensor configuration is complete.
-
splitByteArray(List<int> byteArray, int chunkSize)
→ List<List<int>>
-
-
startGetSensorStateLoop()
→ Stream<SensorConfigStateEntity>
-
Starts a loop to continuously retrieve the sensor state.
-
startScanDevices({String? prefix, int duration = 5000, bool exactMatch = false, ScanStateCallback? scanState, ScanCallback? onResult, FailureCallback? onFailure})
→ void
-
Starts scanning for Bluetooth devices.
-
stopScan()
→ void
-
Stops the ongoing Bluetooth device scan.
-
toString()
→ String
-
A string representation of this object.
inherited
-
writeData(String content, {dynamic onWriteFailure(Exception)?})
→ void
-